#!/usr/bin/python
# -*- coding: utf-8 -*-
#     LICENSE: The GNU Public License v3 or Greater
#
#     WordTeX (wordtex) v0.2.21
#     Copyright 2013 Garrett Berg
#     
#     Loosly based on LaTeX2WP version 0.6.2, Luca Trevisan Copyright 2009
#    
#     This file is part of wordtex, a program that converts
#     a LaTeX document into a format that is ready to be
#     copied and pasted into WordPress.
#    
#     You are free to redistribute and/or modify wordtex under the
#     terms of the GNU General Public License (GPL), version 3
#     or (at your option) any later version.
#    
#     You should have received a copy of the GNU General Public
#     License along with wordtex.  If you can't find it,
#     see <http://www.gnu.org/licenses/>
#!/usr/bin/env python

from distutils.core import setup
import publish
ctb_packages = ['cloudtb', 'cloudtb.extra', 'cloudtb.extra.PyQt', 
                  'cloudtb.tests', 'cloudtb.external',]
ctb_packages = ['wordtex.' + n for n in ctb_packages]
setup(name='wordtex',
      version=publish.VERSION,
      description='Latex to Word Press HTML converter',
      author='Garrett Berg',
      author_email='garrett@cloudformdesign.com',
      url='https://github.com/cloudformdesign/wordtex',
#          modules = ['wordtex', 'wp_formatting', 'texlib'],
      packages = ['wordtex',]+
                  ctb_packages,
      package_dir = {'': '_publish'}
#      packages=['wordtex', 'wordtex.cloudtb'],
     )
    